This is the module where all of the NIF entry points reside. Calling this directly should be avoided unless you are aware of what you are doing.
Summary
Types
@type db() :: reference()
@type reason() :: :atom | String.Chars.t()
@type row() :: list()
@type statement() :: reference()
Functions
@spec bind_blob(statement(), non_neg_integer(), binary()) :: integer()
@spec bind_float(statement(), non_neg_integer(), float()) :: integer()
@spec bind_integer(statement(), non_neg_integer(), integer()) :: integer()
@spec bind_null(statement(), non_neg_integer()) :: integer()
@spec bind_text(statement(), non_neg_integer(), String.t()) :: integer()
@spec reset(statement()) :: :ok
@spec transaction_status(db()) :: {:ok, :idle | :transaction}