A behaviour that defines the API for extensions providing custom data loaders and dumpers for Ecto schemas.
Summary
Callbacks
Takes a value and convers it to data suitable for storage in the database.
A behaviour that defines the API for extensions providing custom data loaders and dumpers for Ecto schemas.
Takes a value and convers it to data suitable for storage in the database.